@@ -7,9 +7,9 @@ __all__ = [
 
 import pickle
 import json
+from lyncs_utils import open_file
 from .format import Formats
-from .utils import open_file
-from . import numpy
+from . import numpy, lime, tar, openqcd
 
 formats = Formats()
 register = formats.register
@@ -80,6 +80,16 @@ register(
     archive=True,
 )
 
+register(
+    "Tar",
+    extensions=tar.all_extensions,
+    head=tar.head,
+    load=tar.load,
+    save=tar.save,
+    description="Tar/Tarball archive format",
+    archive=True,
+)
+
 try:
     from . import hdf5
 
@@ -102,15 +112,23 @@ register(
     **_,
 )
 
-"""
+
 register(
     "lime",
     extensions=["lime"],
-    modules={
-        "lime": "lime",
-        "clime": "lyncs_clime",
-    },
     description="LQCD lime format",
-    archive=True,
+    head=lime.head,
+    load=lime.load,
+    save=lime.save,
+    # archive=True, # Supporting single dataset for now
+)
+
+register(
+    "openqcd",
+    extensions=["oqcd"],
+    description="OpenQCD file format",
+    head=openqcd.head,
+    load=openqcd.load,
+    save=openqcd.save,
+    # archive=True, # Supporting single dataset for now
 )
-"""
